# Nicotine+ Translators

## Dutch
 - hboetes (2021–2022)
 - nince78 (2007)
 - hyriand

## English
 - mathiascode (2020–2022)
 - Michael Labouebe (2016)
 - hyriand
 - daelstorm

## Euskara
 - The Librezale.org Team

## Finnish
 - Kalevi

## French
 - Lisapple (2021–2022)
 - zniavre (2007–2022)
 - melmorabity (2021–2022)
 - m-balthazar (2020)
 - Michael Labouebe (2016–2017)
 - ManWell (2007)
 - flashfr
 - systr

## German
 - hboetes (2021–2022)
 - Meokater (2007)
 - (._.) (2007)
 - lippel (2004)
 - hyriand (2003)

## Hungarian
 - djbaloo

## Italian
 - Gianluca Boiano (2020–2022)
 - Nicola (2007)
 - dbazza

## Lithuanian
 - mantas (2020)
 - Žygimantas Beručka (2006)

## Polish
 - mariachini (2021–2022)
 - Amun-Ra (2007)
 - thine (2007)
 - owczi

## Portuguese Brazilian
 - b1llso (2022)
 - yyyyyyyan (2020)
 - Suicide|Solution (2006)

## Russian
 - SnIPeRSnIPeR (2022)
 - Mehavoid (2021–2022)

## Slovak
 - Josef Riha (2006)

## Spanish
 - tagomago (2021–2022)
 - Strange (2021)
 - Silvio Orta (2007)
 - Dreslo

## Swedish
 - mitramai (2021)
 - alimony

## Turkish
 - Oğuz Ersen (2021–2022)

## Ukrainian
 - uniss2209 (2022)
